/*
 * taskview-io-proxy.h
 *
 * TaskviewIOProxy
 *
 * Copyright © 2010 Salomon Sickert
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 3 of the licence or (at
 * your option) any later version.
 *
 * See the included COPYING file for more information.
 *
 * Authors:
 *    Salomon Sickert <sickert@in.tum.de>
 */

#ifndef __TASKVIEW_IO_PROXY_H__
#define __TASKVIEW_IO_PROXY_H__

#include <glib-object.h>
#include <gio/gio.h>
#include "taskview-generic-proxy.h"

G_BEGIN_DECLS

#define TASKVIEW_TYPE_IO_PROXY	(taskview_io_proxy_get_type ())
#define TASKVIEW_IO_PROXY(obj)	(G_TYPE_CHECK_INSTANCE_CAST ((obj), TASKVIEW_TYPE_IO_PROXY, TaskviewIOProxy))
#define TASKVIEW_IO_PROXY_CLASS(obj)	(G_TYPE_CHECK_CLASS_CAST ((obj), TASKVIEW_TYPE_IO_PROXY, TaskviewIOProxyClass))
#define TASKVIEW_IS_IO_PROXY(obj)	(G_TYPE_CHECK_INSTANCE_TYPE ((obj), TASKVIEW_TYPE_IO_PROXY))
#define TASKVIEW_IS_IO_PROXY_CLASS(obj)	(G_TYPE_CHECK_CLASS_TYPE ((obj), TASKVIEW_TYPE_IO_PROXY))
#define TASKVIEW_IO_PROXY_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), TASKVIEW_TYPE_IO_PROXY, TaskviewIOProxyClass))

typedef struct _TaskviewIOProxy TaskviewIOProxy;
typedef struct _TaskviewIOProxyClass TaskviewIOProxyClass;
typedef struct _TaskviewIOProxyPrivate TaskviewIOProxyPrivate;

struct _TaskviewIOProxy
{
  TaskviewGenericProxy parent;
  TaskviewIOProxyPrivate *priv;
};

struct _TaskviewIOProxyClass
{
  TaskviewGenericProxyClass parent_class;
};

GType taskview_io_proxy_get_type (void);

/* C Wrapper */

gint     taskview_io_proxy_get_io_type (TaskviewIOProxy *self);
guint    taskview_io_proxy_get_current_item (TaskviewIOProxy *self);
GStrv    taskview_io_proxy_get_destination_uri (TaskviewIOProxy *self);
GStrv    taskview_io_proxy_get_source_uri (TaskviewIOProxy *self);
guint64  taskview_io_proxy_get_throughput_size (TaskviewIOProxy *self);
guint64  taskview_io_proxy_get_total_size (TaskviewIOProxy *self);
guint64  taskview_io_proxy_get_processed_size (TaskviewIOProxy *self);
guint64  taskview_io_proxy_get_throughput_items (TaskviewIOProxy *self);
guint64  taskview_io_proxy_get_total_items (TaskviewIOProxy *self);
guint64  taskview_io_proxy_get_processed_items (TaskviewIOProxy *self);

G_END_DECLS

#endif
